unit PluginInterface;

{
   MMB Plugin SDK
   Ported for Delphi by Burton Software
   http://www.burtonsoftware.co.uk

   Do not modify this file
}

interface

uses Windows, SysUtils, PluginInfo, PluginForm;

type
  TColor = Integer;

function GetColor(Input: string): TColor;
procedure SendScriptCommand(Str: string; NoError: Boolean = True);

type
  TPluginMode = (pmDesigner, pmRuntime);

var
  MainForm: TMainForm;

  hMMBWindow: Cardinal;
  PluginMode: TPluginMode;
  AppDir: string;

  TextInput: array [1..5] of string;
  TextOutput: string;
  NumInput: array [1..5] of Integer;
  NumOutput: Integer;

  EventKeys: string;
  EventsOn: Boolean;

implementation

function Copyright: pChar; cdecl;
begin
  Result := pChar(PluginCopyright);
end;

function GetShortInfo: pChar; cdecl;
begin

end;

function GetInfo: pChar; cdecl;
begin
  Result := pChar(PluginInformation);
end;

function GetType: Integer; cdecl;
begin
  Result := 0;
end;

procedure SetPath(sPath: pChar); cdecl;
begin
  AppDir := sPath;
end;

procedure SetParentWindow(hwnd: HWND); cdecl;
begin
  hMMBWindow := hwnd;

  if GetParent(hMMBWindow) <> 0 then
  begin
    PluginMode := pmDesigner;

    MainForm := TMainForm.CreateParented(GetParent(hMMBWindow));
    SetParent(MainForm.Handle, hMMBWindow);
  end else
  begin
    PluginMode := pmRuntime;

    MainForm := TMainForm.CreateParented(hMMBWindow);
  end;
end;

procedure Draw(pDC: HDC; x, y, nWidth, nHeight: Integer); cdecl;
begin
  MainForm.SetBounds(x, y, nWidth, nHeight);
end;

procedure SetFile(s: pChar); cdecl;
begin
  TextInput[5] := TextInput[4];
  TextInput[4] := TextInput[3];
  TextInput[3] := TextInput[2];
  TextInput[2] := TextInput[1];
  TextInput[1] := s;
end;

function GetFile: pChar; cdecl;
begin
  Result := pChar(TextOutput);
end;

procedure SetData(nData: Integer); cdecl;
begin
  NumInput[5] := NumInput[4];
  NumInput[4] := NumInput[3];
  NumInput[3] := NumInput[2];
  NumInput[2] := NumInput[1];
  NumInput[1] := nData;
end;

function GetData: Integer; cdecl;
begin
  Result := NumOutput;
end;

procedure SendScriptCommand(Str: string; NoError: Boolean = True);
begin
  SendMessage(hMMBWindow, $08C7, Integer(not NoError), LPARAM(LPCTSTR(str)));
end;

function GetColor(Input: string): TColor;
var
  R,G,B : Integer;
begin
  try
    R := StrToInt(Copy(Input,1,Pos(',',Input)-1));
    Delete(Input,1,Pos(',',Input));
    G := StrToInt(Copy(Input,1,Pos(',',Input)-1));
    Delete(Input,1,Pos(',',Input));
    B := StrToInt(Copy(Input,1,Length(Input)));
  except
    R := 0;
    G := 0;
    B := 0;
  end;
  Result := StrToInt('$'+IntToHex(B,2) + IntToHex(G,2) + IntToHex(R,2));
end;

exports
  Copyright,
  GetShortInfo,
  GetInfo,
  GetType,
  SetPath,
  SetParentWindow,
  Draw,
  SetFile,
  GetFile,
  SetData,
  GetData;

end.
